==> ckan-2.0.7.tar.gz: ckan-2.0.7/ckan/public/base/i18n/da_DK.js <==
{
  "": {
    "domain": "ckan",
    "lang": "da_DK",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "En fejl opstod"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Er du sikker på, at du vil udføre denne handling?"
  ],
  "Cancel": [
    null,
    "Annuller"
  ],
  "Confirm": [
    null,
    "Bekræft"
  ],
  "Edit": [
    null,
    "Rediger"
  ],
  "Failed to load data API information": [
    null,
    "Kunne ikke indlæse data-API-information"
  ],
  "Follow": [
    null,
    "Følg"
  ],
  "Hide": [
    null,
    "Skjul"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Input er for kort, skal være mindst en karakter"
  ],
  "Loading...": [
    null,
    "Loading..."
  ],
  "No matches found": [
    null,
    "Ingen resultater fundet"
  ],
  "Please Confirm Action": [
    null,
    "Bekræft venligst handling"
  ],
  "Resource uploaded": [
    null,
    "Ressource uploadet"
  ],
  "Show more": [
    null,
    "Vis mere"
  ],
  "Start typing…": [
    null,
    "Begynd indtastning..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Ændringer til denne formular er ikke gemt"
  ],
  "There is no API data to load for this resource": [
    null,
    "Der er ingen API-data at indlæse for denne ressource"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Ude af stand til at autentificere upload"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Ude af stand til at hente data for uploadet fil"
  ],
  "Unable to upload file": [
    null,
    "Ude af stand til at uploade fil"
  ],
  "Unfollow": [
    null,
    "Følg ikke"
  ],
  "Upload a file": [
    null,
    "Upload en fil"
  ],
  "show less": [
    null,
    "Vis færre"
  ],
  "show more": [
    null,
    "Vis flere"
  ]
}

==> ckan-2.1.tar.gz: ckan-2.1/ckan/public/base/i18n/da_DK.js <==
{
  "": {
    "domain": "ckan",
    "lang": "da_DK",
    "plural-forms": "nplurals=2; plural=(n != 1);"
  },
  "An Error Occurred": [
    null,
    "Der opstod en fejl"
  ],
  "Are you sure you want to perform this action?": [
    null,
    "Er du sikker på, at du vil udføre denne handling?"
  ],
  "Cancel": [
    null,
    "Annullér"
  ],
  "Confirm": [
    null,
    "Bekræft"
  ],
  "Edit": [
    null,
    "Redigér"
  ],
  "Failed to load data API information": [
    null,
    "Kunne ikke indlæse data-API-information"
  ],
  "Follow": [
    null,
    "Følg"
  ],
  "Hide": [
    null,
    "Skjul"
  ],
  "Input is too short, must be at least one character": [
    null,
    "Input er for kort, skal være mindst én karakter"
  ],
  "Loading...": [
    null,
    "Loading..."
  ],
  "No matches found": [
    null,
    "Ingen resultater fundet"
  ],
  "Please Confirm Action": [
    null,
    "Bekræft venligst handling"
  ],
  "Resource uploaded": [
    null,
    "Ressource uploadet"
  ],
  "Show more": [
    null,
    "Vis mere"
  ],
  "Start typing…": [
    null,
    "Begynd indtastning..."
  ],
  "There are unsaved modifications to this form": [
    null,
    "Der er ændringer til denne formular som ikke er gemt"
  ],
  "There is no API data to load for this resource": [
    null,
    "Der er ingen API-data at indlæse for denne ressource"
  ],
  "URL": [
    null,
    "URL"
  ],
  "Unable to authenticate upload": [
    null,
    "Ude af stand til at autentificere upload"
  ],
  "Unable to get data for uploaded file": [
    null,
    "Ude af stand til at hente data for uploadet fil"
  ],
  "Unable to upload file": [
    null,
    "Ude af stand til at uploade fil"
  ],
  "Unfollow": [
    null,
    "Følg ikke"
  ],
  "Upload a file": [
    null,
    "Upload en fil"
  ],
  "You are uploading a file. Are you sure you want to navigate away and stop this upload?": [
    null,
    "Du uploader en fil. Er du sikker på, du vil navigere væk og standse upload?"
  ],
  "show less": [
    null,
    "vis færre"
  ],
  "show more": [
    null,
    "vis flere"
  ]
}
